==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebPositionSettingsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebPositionSettingsDescription = /*@__PURE__*/ (() => {
    class WebPositionSettingsDescription extends Description {
        constructor() {
            super();
            this.h = null;
            this.j = null;
            this.l = null;
            this.k = null;
            this.m = null;
            this.f = null;
        }
        get_type() {
            return "WebPositionSettings";
        }
        get type() {
            return this.get_type();
        }
        get target() {
            return this.h;
        }
        set target(a) {
            this.h = a;
            this.e("Target");
        }
        get horizontalDirection() {
            return this.j;
        }
        set horizontalDirection(a) {
            this.j = a;
            this.e("HorizontalDirection");
        }
        get verticalDirection() {
            return this.l;
        }
        set verticalDirection(a) {
            this.l = a;
            this.e("VerticalDirection");
        }
        get horizontalStartPoint() {
            return this.k;
        }
        set horizontalStartPoint(a) {
            this.k = a;
            this.e("HorizontalStartPoint");
        }
        get verticalStartPoint() {
            return this.m;
        }
        set verticalStartPoint(a) {
            this.m = a;
            this.e("VerticalStartPoint");
        }
        get minSize() {
            return this.f;
        }
        set minSize(a) {
            this.f = a;
            this.e("MinSize");
        }
    }
    WebPositionSettingsDescription.$t = /*@__PURE__*/ markType(WebPositionSettingsDescription, 'WebPositionSettingsDescription', Description.$);
    return WebPositionSettingsDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebPositionSettingsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebPositionSettingsDescription = /*@__PURE__*/ (() => {
    class WebPositionSettingsDescription extends Description {
        get_type() {
            return "WebPositionSettings";
        }
        get type() {
            return this.get_type();
        }
        constructor() {
            super();
            this.j = null;
            this.l = null;
            this.k = null;
            this.m = null;
            this.h = null;
        }
        get horizontalDirection() {
            return this.j;
        }
        set horizontalDirection(a) {
            this.j = a;
            this.g("HorizontalDirection");
        }
        get verticalDirection() {
            return this.l;
        }
        set verticalDirection(a) {
            this.l = a;
            this.g("VerticalDirection");
        }
        get horizontalStartPoint() {
            return this.k;
        }
        set horizontalStartPoint(a) {
            this.k = a;
            this.g("HorizontalStartPoint");
        }
        get verticalStartPoint() {
            return this.m;
        }
        set verticalStartPoint(a) {
            this.m = a;
            this.g("VerticalStartPoint");
        }
        get minSize() {
            return this.h;
        }
        set minSize(a) {
            this.h = a;
            this.g("MinSize");
        }
    }
    WebPositionSettingsDescription.$t = /*@__PURE__*/ markType(WebPositionSettingsDescription, 'WebPositionSettingsDescription', Description.$);
    return WebPositionSettingsDescription;
})();
